@@ -469,7 +469,7 @@ start_ssh (unsigned spawn_flags, struct config *config,
    * We don't know how command line editing is set up
    * (https://bugzilla.redhat.com/1314244#c9).
    */
-  if (mexp_printf (h, "exec bash --noediting --noprofile\n") == -1) {
+  if (mexp_printf (h, "exec bash --noediting --noprofile --norc\n") == -1) {
     set_ssh_mexp_error ("mexp_printf");
     mexp_close (h);
     return NULL;
@@ -1015,11 +1015,10 @@ static void
 add_output_driver (const char *name)
 {
   /* Ignore the 'vdsm' driver, since that should only be used by VDSM.
-   * Ignore the 'openstack' and 'rhv-upload' drivers, since we do not
-   * support passing all the options for them.
+   * Ignore the 'rhv-upload' driver, since we do not support passing all the
+   * options for it.
    */
   if (STRNEQ (name, "vdsm") &&
-      STRNEQ (name, "openstack") &&
       STRNEQ (name, "rhv-upload"))
     add_option ("output", &output_drivers, name);
 }
